@@ -21,7 +21,7 @@
 
 use strict ;
 
-use version ; our $VERSION = "1.95" ;
+use version ; our $VERSION = "1.96" ;
 
 package uHTMLnode;
 
@@ -775,13 +775,13 @@ sub _struct( $$$ )
   }
   $Struct = $Prev ;
 
-  while( $tag = ($String =~ m/\G<(\/?[\w-]+|[!?*])/sgc)[0] )
+  while( $tag = ($String =~ m/\G<(\/?[\w:-]+|[!?*])/sgc)[0] )
   {
-    if( $tag =~ m/^[\w-]+$/s )
+    if( $tag =~ m/^\w[\w:-]*$/s )
     {
       my( %Attributes ) ;
 
-      while( $String =~ m/\G\s*([\w-]+)\s*(?:\=\s*("(?:[^"]|\\")*(?<!\\)"|'(?:[^']|\\')*(?<!\\)'|[^\s>]+))?/sgc )
+      while( $String =~ m/\G\s*(\w[\w:-]*)\s*(?:\=\s*("(?:[^"]|\\")*(?<!\\)"|'(?:[^']|\\')*(?<!\\)'|[^\s>]+))?/sgc )
       {
         $par = $1 ;
         $val = $2 ;
@@ -804,7 +804,7 @@ sub _struct( $$$ )
       $New = uHTMLnode->new( $tag,$1,$Prev,$env ) ;
       $New->attributes( \%Attributes ) if %Attributes ;
     }
-    elsif( $tag =~ m/^\/([\w-]+)$/s )
+    elsif( $tag =~ m/^\/(\w[\w:-]*)$/s )
     {
       $tag = $1 ;
       $String =~ m/\G\s*\>([^<]*)/sgc ;
